@@ -80,7 +80,7 @@ Fishconsole Project
 
 
 
-__all__ = ["files","logs", "window", "helps", "fcv", "huitu", "Fishsys"]
+__all__ = ["files","logs", "window", "helps", "fcv", "huitu", "Fishsys","Fishconsole_version_a","Fishconsole_version_a"]
 
 def Fishconsole_project():
     from Fishconsole import fcv
