@@ -10,13 +10,13 @@
 主要是这个太大了，我没心情写
 
 """
-
-import datetime
-模块开始 = datetime.datetime.now()
-
-import matplotlib.pyplot as plt
 from Fishconsole import logs
-from Fishconsole import Fishsys
+try:
+    import matplotlib.pyplot as plt
+    from Fishconsole import logs
+    from Fishconsole import Fishsys
+except:
+    logs.安全退出("huitu依赖包导入出错，程序无法运行")
 
 def 单线折线图(x轴范围, x轴数据源: list, y轴范围, y轴数据源: list, 网格线=False, x轴名="x", y轴名="y", 线的样式="-", 线的颜色="b", 线的宽度=2, 画布长=6, 画布宽=6,
           标题=None,
@@ -404,4 +404,3 @@ def 饼图(数据: list, 数据标签: list = None, 数据颜色: list = None, 
 
 
 
-模块结束 = datetime.datetime.now()
\ No newline at end of file
